pub enum CobsError {
Truncated,
Corrupt,
}Expand description
Errors that can occur while decoding.
Variants
Truncated
The input ended without completing the last run or without the trailing zero byte, suggesting that part of it is missing. (This can also occur spuriously if you pick up in the middle of a stream without finding the first zero.)
Corrupt
The input contained an unexpected zero byte. Not all decode methods promise to detect this case.